@@ -12,7 +12,7 @@ from conftest import skip_gitlab_ci
 from unittest.mock import Mock, patch
 
 from ae.base import PY_CACHE_FOLDER, PY_INIT, norm_name
-from aedev.pythonanywhere import SKIP_ROOT_FOLDERS, PythonanywhereApi
+from aedev.pythonanywhere import PythonanywhereApi
 
 
 TEST_PROJECT_NAME = 'aedev_pythonanywhere_tests'    #: package name used for integrity tests on web server
@@ -87,8 +87,6 @@ def con_pkg(connection):
 def test_pythonanywhere_declarations():
     """ test the module declarations (also for having at least one test case running on gitlab ci). """
     assert PythonanywhereApi
-    assert SKIP_ROOT_FOLDERS
-    assert isinstance(SKIP_ROOT_FOLDERS, tuple)
 
     assert norm_name(TEST_PROJECT_NAME) == TEST_PROJECT_NAME
 
@@ -304,23 +302,28 @@ class TestHostRunningOnlyLocallyWithPatchedSkipper:
 
         found_paths = con_pkg.deployed_code_files(['*/**/media*/*'])
         assert con_pkg.error_message == ""
-        assert found_paths == set()                         # media and media_ini folders filtered out
-
-        found_paths = con_pkg.deployed_code_files(['*/**/migrations/*'])
-        assert con_pkg.error_message == ""
-        assert found_paths == set()                         # migrations folders get filtered out by web_file_exclude()
+        assert found_paths == set()                         # there are no deep folders with media*
 
         found_paths = con_pkg.deployed_code_files(['**/migrations/' + mig_file_name])
         assert con_pkg.error_message == ""
-        assert found_paths == set()
+        assert found_paths == {mig_file_path}
 
-        found_paths = con_pkg.deployed_code_files(['**/static/*'], lean=True)
+        found_paths = con_pkg.deployed_code_files(['*/*/**/migrations/*'])
         assert con_pkg.error_message == ""
-        assert found_paths == {pkg2_static_file}            # static_ini_file + pkg0_static_file get excluded
+        assert found_paths == {mig_file_path}               # migrations folders are always deeper (not on project root)
 
-        found_paths = con_pkg.deployed_code_files(['**/static/*'])
+        found_paths = con_pkg.deployed_code_files(['*/*/*/**/migrations/*'])
         assert con_pkg.error_message == ""
-        assert found_paths == {pkg2_static_file}            # static_ini_file + pkg0_static_file get excluded
+        assert found_paths == set()                         # .. but not that deep in the test project
+
+        found_paths = con_pkg.deployed_code_files(['**/static/*'], skip_file_path=lambda fp: fp.startswith('static/'))
+        assert con_pkg.error_message == ""
+        assert found_paths == {pkg0_static_file, pkg2_static_file}  # static_ini_file  get excluded
+
+        found_paths = con_pkg.deployed_code_files(['**/static/*'],
+                                                  skip_file_path=lambda _: _.startswith(f'{TEST_PROJECT_NAME}/static/'))
+        assert con_pkg.error_message == ""
+        assert found_paths == {static_ini_file, pkg2_static_file}   # pkg0_static_file get excluded
 
     def test_find_project_files(self, con_pkg):
         con_pkg.error_message = ""                          # clear con_pkg instance error from previous test method
@@ -380,22 +383,3 @@ class TestHostRunningOnlyLocallyWithPatchedSkipper:
         assert sub_dir_path in con_pkg.error_message
 
         con_pkg.error_message = ""                          # clear con_pkg instance error
-
-
-class TestPythonAnywhereWithoutConnection:
-    def test_web_file_exclude(self):
-        instance = PythonanywhereApi("any domain", "any user", "any token", TEST_PROJECT_NAME)
-
-        for file_path in all_pkg_paths | skipped_lean_paths:
-            assert not instance.web_file_exclude(file_path)
-
-        for file_path in all_pkg_paths:
-            assert not instance.web_lean_file_exclude(file_path)
-
-        assert instance.web_file_exclude(os.path.join('migrations', "any filename"))
-        assert instance.web_file_exclude(os.path.join('root_folder', 'migrations', "any filename"))
-
-        for folder in SKIP_ROOT_FOLDERS:
-            assert instance.web_file_exclude(os.path.join(folder, "any filename"))
-            assert not instance.web_file_exclude(os.path.join("any root folder", folder))
-            assert not instance.web_file_exclude(os.path.join("any root folder", folder, "any filename"))
